@@ -44,13 +44,13 @@ class InvalidEnv(Exception):
 
 
 try:
-    load_dotenv('./.env')
+    load_dotenv("./.env")
     os.environ["EMBED_COLOR"]
 except KeyError:
     with open("./.env", "a") as env:
         env.write("\n#disnake-debug\nEMBED_COLOR = 0x0000ff")
 try:
-    load_dotenv('./.env')
+    load_dotenv("./.env")
     EMBED_COLOR = int(os.environ["EMBED_COLOR"], 16)
 except (TypeError, ValueError):
     raise InvalidEnv("EMBED_COLOR must be hex")
