@@ -74,7 +74,9 @@ class Change(View):
             (message := await self.bot.wait_for("message", check=self.check))
         ).attachments:
             if message.content == "q":
-                return await interaction.message.reply("Cancelled the current `wait_for`")
+                return await interaction.message.reply(
+                    "Cancelled the current `wait_for`"
+                )
             await interaction.message.reply("You must send an image file!")
 
         try:
