@@ -2,7 +2,14 @@ from ..utils import EmbedFactory, MainMenu, get_bot_message
 from fuzzywuzzy import fuzz
 from typing import List
 
-from disnake import MessageInteraction, Message, SelectOption, Guild, Forbidden, ButtonStyle
+from disnake import (
+    MessageInteraction,
+    Message,
+    SelectOption,
+    Guild,
+    Forbidden,
+    ButtonStyle,
+)
 from disnake.ui import Select, View, Button, button
 from disnake.ext.commands import Bot, Context
 
